@@ -285,7 +285,7 @@ bool KmPlotIO::restore(const QDomDocument &doc)
             }
         }
     } else {
-        KMessageBox::sorry(0, i18n("The file had an unknown version number"));
+        KMessageBox::error(0, i18n("The file had an unknown version number"));
         return false;
     }
 
@@ -303,14 +303,14 @@ bool KmPlotIO::load(const QUrl &url)
     bool downloadedFile = false;
     if (!url.isLocalFile()) {
         if (!MainDlg::fileExists(url)) {
-            KMessageBox::sorry(0, i18n("The file does not exist."));
+            KMessageBox::error(0, i18n("The file does not exist."));
             return false;
         }
         downloadedFile = true;
         KIO::StoredTransferJob *transferjob = KIO::storedGet(url);
         KJobWidgets::setWindow(transferjob, 0);
         if (!transferjob->exec()) {
-            KMessageBox::sorry(0, i18n("An error appeared when opening this file (%1)", transferjob->errorString()));
+            KMessageBox::error(0, i18n("An error appeared when opening this file (%1)", transferjob->errorString()));
             return false;
         }
         QTemporaryFile file;
@@ -323,13 +323,13 @@ bool KmPlotIO::load(const QUrl &url)
         f.setFileName(url.toLocalFile());
 
     if (!f.open(QIODevice::ReadOnly)) {
-        KMessageBox::sorry(0, i18n("%1 could not be opened", f.fileName()));
+        KMessageBox::error(0, i18n("%1 could not be opened", f.fileName()));
         return false;
     }
     QString errorMessage;
     int errorLine, errorColumn;
     if (!doc.setContent(&f, &errorMessage, &errorLine, &errorColumn)) {
-        KMessageBox::sorry(0, i18n("%1 could not be loaded (%2 at line %3, column %4)", f.fileName(), errorMessage, errorLine, errorColumn));
+        KMessageBox::error(0, i18n("%1 could not be loaded (%2 at line %3, column %4)", f.fileName(), errorMessage, errorLine, errorColumn));
         f.close();
         return false;
     }
@@ -525,7 +525,7 @@ void KmPlotIO::parseParameters(const QDomElement &n, Function *function)
     QChar separator = (version < 1) ? ',' : ';';
     QString tagName = (version < 4) ? "parameterlist" : "parameter-list";
 
-    const QStringList str_parameters = n.namedItem(tagName).toElement().text().split(separator, QString::SkipEmptyParts);
+    const QStringList str_parameters = n.namedItem(tagName).toElement().text().split(separator, Qt::SkipEmptyParts);
     for (QStringList::const_iterator it = str_parameters.constBegin(); it != str_parameters.constEnd(); ++it)
         function->m_parameters.list.append(Value(*it));
 }
@@ -717,7 +717,7 @@ void KmPlotIO::oldParseFunction(const QDomElement &n)
     else {
         ufkt.eq[0]->setFstr(tmp_fstr.left(pos), 0, 0, true);
         if (!XParser::self()->getext(&ufkt, tmp_fstr)) {
-            KMessageBox::sorry(0, i18n("The function %1 could not be loaded", ufkt.eq[0]->fstr()));
+            KMessageBox::error(0, i18n("The function %1 could not be loaded", ufkt.eq[0]->fstr()));
             return;
         }
     }
@@ -754,7 +754,7 @@ QString KmPlotIO::gradientToString(const QGradientStops &stops)
 // static
 QGradientStops KmPlotIO::stringToGradient(const QString &string)
 {
-    const QStringList stopStrings = string.split(',', QString::SkipEmptyParts);
+    const QStringList stopStrings = string.split(',', Qt::SkipEmptyParts);
 
     QGradientStops stops;
     for (const QString &stopString : stopStrings) {
