@@ -27,6 +27,7 @@
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
 #include <KMessageBox>
+#include <kwidgetsaddons_version.h>
 
 #include "maindlg.h"
 
@@ -201,7 +202,7 @@ void KParameterEditor::cmdImport_clicked()
         return;
 
     if (!MainDlg::fileExists(url)) {
-        KMessageBox::sorry(0, i18n("The file does not exist."));
+        KMessageBox::error(0, i18n("The file does not exist."));
         return;
     }
 
@@ -211,7 +212,7 @@ void KParameterEditor::cmdImport_clicked()
         KIO::StoredTransferJob *transferjob = KIO::storedGet(url);
         KJobWidgets::setWindow(transferjob, 0);
         if (!transferjob->exec()) {
-            KMessageBox::sorry(0, i18n("An error appeared when opening this file: %1", transferjob->errorString()));
+            KMessageBox::error(0, i18n("An error appeared when opening this file: %1", transferjob->errorString()));
             return;
         }
         QTemporaryFile tmpfile;
@@ -245,18 +246,26 @@ void KParameterEditor::cmdImport_clicked()
                     file.close();
                     QFile::remove(file.fileName());
                     return;
+#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 100, 0)
                 } else if (KMessageBox::warningYesNo(this,
+#else
+                } else if (KMessageBox::warningTwoActions(this,
+#endif
                                                      i18n("Would you like to be informed about other lines that cannot be read?"),
                                                      QString(),
                                                      KGuiItem(i18n("Get Informed")),
                                                      KGuiItem(i18n("Ignore Information")))
+#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 100, 0)
                            == KMessageBox::No)
+#else
+                           == KMessageBox::SecondaryAction)
+#endif
                     verbose = true;
             }
         }
         file.close();
     } else
-        KMessageBox::sorry(0, i18n("An error appeared when opening this file"));
+        KMessageBox::error(0, i18n("An error appeared when opening this file"));
 
     if (!url.isLocalFile())
         QFile::remove(file.fileName());
@@ -290,14 +299,14 @@ void KParameterEditor::cmdExport_clicked()
                 }
                 stream.flush();
             } else
-                KMessageBox::sorry(0, i18n("An error appeared when saving this file"));
+                KMessageBox::error(0, i18n("An error appeared when saving this file"));
 
             Q_CONSTEXPR int permission = -1;
             QFile file(tmpfile.fileName());
             file.open(QIODevice::ReadOnly);
             KIO::StoredTransferJob *putjob = KIO::storedPut(file.readAll(), url, permission, KIO::JobFlag::Overwrite);
             if (!putjob->exec()) {
-                KMessageBox::sorry(0, i18n("An error appeared when saving this file"));
+                KMessageBox::error(0, i18n("An error appeared when saving this file"));
                 return;
             }
             file.close();
@@ -315,7 +324,7 @@ void KParameterEditor::cmdExport_clicked()
                 }
                 file.close();
             } else
-                KMessageBox::sorry(0, i18n("An error appeared when saving this file"));
+                KMessageBox::error(0, i18n("An error appeared when saving this file"));
         }
     }
 }
