@@ -533,10 +533,9 @@ int Parser::addFunction(const QString &str1, const QString &str2, Function::Type
     m_ufkt[temp->id()] = temp;
 
     temp->plotAppearance(Function::Derivative0).color = XParser::self()->defaultColor(temp->id());
-    // Better use QRandomGenerator::global()->generate() instead of qrand() since Qt 5.10
-    temp->plotAppearance(Function::Derivative1).color = QColor::fromRgb(qrand());
-    temp->plotAppearance(Function::Derivative2).color = QColor::fromRgb(qrand());
-    temp->plotAppearance(Function::Integral).color = QColor::fromRgb(qrand());
+    temp->plotAppearance(Function::Derivative1).color = QColor::fromRgb(QRandomGenerator::global()->generate());
+    temp->plotAppearance(Function::Derivative2).color = QColor::fromRgb(QRandomGenerator::global()->generate());
+    temp->plotAppearance(Function::Integral).color = QColor::fromRgb(QRandomGenerator::global()->generate());
 
     emit functionAdded(temp->id());
     return temp->id(); // return the unique ID-number for the function
@@ -1130,7 +1129,7 @@ void Parser::displayErrorDialog(Error error)
 {
     QString message(errorString(error));
     if (!message.isEmpty())
-        KMessageBox::sorry(0, message, QStringLiteral("KmPlot"));
+        KMessageBox::error(0, message, QStringLiteral("KmPlot"));
 }
 
 QString Parser::evalRemaining()
@@ -1382,7 +1381,7 @@ void ExpressionSanitizer::fixExpression(QString *str)
 
     // make sure all minus-like signs (including the actual unicode minus sign)
     // are represented by a dash (unicode 0x002d)
-    QChar dashes[6] = {0x2012, 0x2013, 0x2014, 0x2015, 0x2053, 0x2212};
+    QChar dashes[6] = {QChar(0x2012), QChar(0x2013), QChar(0x2014), QChar(0x2015), QChar(0x2053), QChar(0x2212)};
     for (unsigned i = 0; i < 6; ++i)
         replace(dashes[i], '-');
 
